@@ -1,14 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "orgit" "2.1.2"
+(define-package "orgit" "20251101.2137"
   "Support for Org links to Magit buffers."
-  '((emacs    "28.1")
-    (compat   "30.1")
-    (cond-let "0.2")
-    (magit    "4.5")
-    (org      "9.7"))
+  '((emacs  "28.1")
+    (compat "30.1")
+    (magit  "4.4")
+    (org    "9.7"))
   :url "https://github.com/magit/orgit"
-  :commit "4fb91faff3bf32dac5f6f932654c280cd1f190f7"
-  :revdesc "v2.1.2-0-g4fb91faff3bf"
+  :commit "9a171dfc7775c9286318b26710fcbf223fbde056"
+  :revdesc "9a171dfc7775"
   :keywords '("hypermedia" "vc")
   :authors '(("Jonas Bernoulli" . "emacs.orgit@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.orgit@jonas.bernoulli.dev")))
